/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.projecteer.metadata.entity;

/**
 * An {@link Entity} is a {@link Person}, {@link Group}, or something else that
 * is, in some way, linked to a project.
 * <br /> <br />
 * This may include programmers, founding members, lawyers, contributors, et cetera
 *
 * @author Cruz Julian Bishop
 * @since 1.0.0.0
 */
public interface Entity extends Cloneable {
    
    /**
     * Gets this {@link Entity}'s name
     * 
     * @return The name of this {@link Entity}
     * @since 1.0.0.0
     */
    String getName();
    
    /**
     * Sets this {@link Entity}'s name
     * 
     * @param name The name to set
     * @since 1.0.0.0
     */
    void setName(String name);
    
    /**
     * Gets this {@link Entity}'s role
     * 
     * @return The role of this {@link Entity}
     * @since 1.0.0.0
     */
    String getRole();
    
    /**
     * Sets this {@link Entity}'s role
     * 
     * @param role The role to set
     * @since 1.0.0.0
     */
    void setRole(String role);
    
    /**
     * Gets this {@link Entity}'s email address
     * 
     * @return The email address of this {@link Entity}
     * @since 1.0.0.0
     */
    String getEmailAddress();
    
    /**
     * Sets this {@link Entity}'s email address
     * 
     * @param emailAddress The email address to set
     * @since 1.0.0.0
     */
    void setEmailAddress(String emailAddress);
    
    /**
     * Clones this {@link Entity}
     * 
     * @return The cloned {@link Entity}
     * @since 1.0.0.0
     */
    Entity clone();
    
}
