/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.projecteer.metadata.version;

/**
 * An enumeration defining different types of versions
 *
 * @author Cruz Julian Bishop
 * @since 1.0.0.0
 */
public enum VersionType {
    
    /**
     * A snapshot {@link VersionType}, which is usually still being developed.
     * <br />
     * It is strongly not recommended to use a project with a Version with this type.
     * 
     * @since 1.0.0.0
     */
    SNAPSHOT,
    
    /**
     * An alpha {@link VersionType}, which is usually an early testing release.
     * <br />
     * It is usually not recommended to use a project with a Version with this 
     * type, as it may have severe bugs and imminent API changes
     * 
     * @since 1.0.0.0
     */
    ALPHA,
    
    /**
     * A beta {@link VersionType}, which is usually a testing release.
     * <br />
     * It is sometimes not recommended to use a project with a Version of this
     * VersionType, as it may still have some bugs and imminent API changes.
     * 
     * @since 1.0.0.0
     */
    BETA,
    
    /**
     * A release candidate {@link VersionType}, which is usually the last release
     * before a stable {@link VersionType} is used.
     * <br />
     * It is usually safe to use a project with a Version of this {@link VersionType},
     * however, there may be a few hidden bugs
     * 
     * @since 1.0.0.0
     */
    RELEASE_CANDIDATE,
    
    /**
     * A stable {@link VersionType}, indicating a usable project release.
     * 
     * @since 1.0.0.0
     */
    STABLE
    
}
